==> 0.1.41.tar.gz: lib/widgets/settings/widget_languages.dart <==
import 'package:flutter/material.dart';
import '../widget_bottom_sheet_base.dart';

class WidgetSettingLanguages extends StatefulWidget {
  final List<Locale> supportedlocale;
  final dynamic getLanguageLabel;
  final dynamic onTap;
  final dynamic style;
  final dynamic getLocale;
  final dynamic selectedColor;
  const WidgetSettingLanguages({
    Key? key,
    required this.getLanguageLabel,
    required this.getLocale,
    required this.onTap,
    required this.selectedColor,
    required this.style,
    required this.supportedlocale,
  }) : super(key: key);

  @override
  _WidgetSettingLanguagesState createState() => _WidgetSettingLanguagesState();
}

class _WidgetSettingLanguagesState extends State<WidgetSettingLanguages> {
  String keyword = '';

  @override
  Widget build(BuildContext context) {
    return WidgetBottomBarApp(
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          const SizedBox(
            height: 36,
          ),
          // Text(
          //   AppLocaleKeys.choose_lang,
          //   textAlign: TextAlign.center,
          //   style: AppTextStyles.normalBold.copyWith(fontSize: 24),
          // ),

          ...widget.supportedlocale
              .where((e) => widget
                  .getLanguageLabel(e)
                  .toUpperCase()
                  .contains(keyword.toUpperCase()))
              .map((e) => _buildOption(e))
              .toList(),

          const SizedBox(
            height: 36,
          ),
        ],
      ),
    );
  }

  Widget _buildOption(Locale locale) {
    String value = widget.getLanguageLabel(locale);

    return InkWell(
      onTap: () => widget.onTap(locale),
      child: Padding(
        padding: const EdgeInsets.symmetric(vertical: 24.0),
        child: Row(
          mainAxisSize: MainAxisSize.min,
          children: [
            CircleAvatar(
              radius: 6,
              backgroundColor: checkSelected(locale)
                  ? widget.selectedColor
                  : Colors.transparent,
            ),
            const SizedBox(
              width: 16,
            ),
            Text(
              value,
              style: widget.style,
            ),
            const CircleAvatar(
              radius: 6,
              backgroundColor: Colors.transparent,
            ),
            const SizedBox(
              width: 16,
            ),
          ],
        ),
      ),
    );
  }

  bool checkSelected(Locale locale) {
    return locale.languageCode == widget.getLocale().languageCode;
  }
}

==> 0.1.47.tar.gz: lib/widgets/settings/widget_languages.dart <==
import 'package:flutter/material.dart';
import '../widget_bottom_sheet_base.dart';

class WidgetSettingLanguages extends StatefulWidget {
  final List<Locale> supportedlocale;
  final dynamic getLanguageLabel;
  final dynamic onTap;
  final dynamic style;
  final dynamic getLocale;
  final dynamic selectedColor;
  const WidgetSettingLanguages({
    Key? key,
    required this.getLanguageLabel,
    required this.getLocale,
    required this.onTap,
    required this.selectedColor,
    required this.style,
    required this.supportedlocale,
  }) : super(key: key);

  @override
  _WidgetSettingLanguagesState createState() => _WidgetSettingLanguagesState();
}

class _WidgetSettingLanguagesState extends State<WidgetSettingLanguages> {
  String keyword = '';

  @override
  Widget build(BuildContext context) {
    return WidgetBottomBarApp(
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          const SizedBox(
            height: 36,
          ),
          // Text(
          //   AppLocaleKeys.choose_lang,
          //   textAlign: TextAlign.center,
          //   style:  normalBold.copyWith(fontSize: 24),
          // ),

          ...widget.supportedlocale
              .where((e) => widget
                  .getLanguageLabel(e)
                  .toUpperCase()
                  .contains(keyword.toUpperCase()))
              .map((e) => _buildOption(e))
              .toList(),

          const SizedBox(
            height: 36,
          ),
        ],
      ),
    );
  }

  Widget _buildOption(Locale locale) {
    String value = widget.getLanguageLabel(locale);

    return InkWell(
      onTap: () => widget.onTap(locale),
      child: Padding(
        padding: const EdgeInsets.symmetric(vertical: 24.0),
        child: Row(
          mainAxisSize: MainAxisSize.min,
          children: [
            CircleAvatar(
              radius: 6,
              backgroundColor: checkSelected(locale)
                  ? widget.selectedColor
                  : Colors.transparent,
            ),
            const SizedBox(
              width: 16,
            ),
            Text(
              value,
              style: widget.style,
            ),
            const CircleAvatar(
              radius: 6,
              backgroundColor: Colors.transparent,
            ),
            const SizedBox(
              width: 16,
            ),
          ],
        ),
      ),
    );
  }

  bool checkSelected(Locale locale) {
    return locale.languageCode == widget.getLocale().languageCode;
  }
}
